@@ -14,49 +14,8 @@
  * limitations under the License.
  */
 
-/**
- * $Log: NameIdPool.c,v $
- * Revision 1.9  2004/09/08 13:56:22  peiyongz
- * Apache License Version 2.0
- *
- * Revision 1.8  2003/12/17 00:18:35  cargilld
- * Update to memory management so that the static memory manager (one used to call Initialize) is only for static data.
- *
- * Revision 1.7  2003/10/29 16:18:05  peiyongz
- * size() added and Reset() bug fixed
- *
- * Revision 1.6  2003/05/16 06:01:52  knoaman
- * Partial implementation of the configurable memory manager.
- *
- * Revision 1.5  2003/05/15 19:04:35  knoaman
- * Partial implementation of the configurable memory manager.
- *
- * Revision 1.4  2002/11/04 15:22:04  tng
- * C++ Namespace Support.
- *
- * Revision 1.3  2002/09/24 19:51:24  tng
- * Performance: use XMLString::equals instead of XMLString::compareString
- *
- * Revision 1.2  2002/05/08 19:05:29  knoaman
- * [Bug 7701] NameIdPoolEnumerator copy constructor should call base class - fix by Martin Kalen
- *
- * Revision 1.1.1.1  2002/02/01 22:22:11  peiyongz
- * sane_include
- *
- * Revision 1.3  2000/03/02 19:54:42  roddey
- * This checkin includes many changes done while waiting for the
- * 1.1.0 code to be finished. I can't list them all here, but a list is
- * available elsewhere.
- *
- * Revision 1.2  2000/02/06 07:48:02  rahulj
- * Year 2K copyright swat.
- *
- * Revision 1.1.1.1  1999/11/09 01:04:47  twl
- * Initial checkin
- *
- * Revision 1.3  1999/11/08 20:45:10  rahul
- * Swat for adding in Product name and CVS comment log variable.
- *
+/*
+ * $Id: NameIdPool.c 191054 2005-06-17 02:56:35Z jberry $
  */
 
 
@@ -70,6 +29,8 @@
 #include <xercesc/util/IllegalArgumentException.hpp>
 #include <xercesc/util/NoSuchElementException.hpp>
 #include <xercesc/util/RuntimeException.hpp>
+#include <new>
+#include <assert.h>
 
 XERCES_CPP_NAMESPACE_BEGIN
 
@@ -168,7 +129,9 @@ template <class TElem> void NameIdPool<TElem>::removeAll()
             nextElem = curElem->fNext;
 
             delete curElem->fData;
-            delete curElem;
+            // destructor is empty...
+            // curElem->~NameIdPoolBucketElem();
+            fMemoryManager->deallocate(curElem);
 
             curElem = nextElem;
         }
@@ -251,11 +214,9 @@ unsigned int NameIdPool<TElem>::put(TElem* const elemToAdopt)
     }
 
     // Create a new bucket element and add it to the appropriate list
-    NameIdPoolBucketElem<TElem>* newBucket = new (fMemoryManager) NameIdPoolBucketElem<TElem>
-    (
-        elemToAdopt
-        , fBucketList[hashVal]
-    );
+    NameIdPoolBucketElem<TElem>* newBucket =
+        new (fMemoryManager->allocate(sizeof(NameIdPoolBucketElem<TElem>)))
+        NameIdPoolBucketElem<TElem>(elemToAdopt,fBucketList[hashVal]);
     fBucketList[hashVal] = newBucket;
 
     //
@@ -300,8 +261,7 @@ findBucketElem(const XMLCh* const key, unsigned int& hashVal)
     // Hash the key
     hashVal = XMLString::hash(key, fHashModulus, fMemoryManager);
 
-    if (hashVal > fHashModulus)
-        ThrowXMLwithMemMgr(RuntimeException, XMLExcepts::Pool_BadHashFromKey, fMemoryManager);
+    assert(hashVal < fHashModulus);        
 
     // Search that bucket for the key
     NameIdPoolBucketElem<TElem>* curElem = fBucketList[hashVal];
@@ -321,8 +281,7 @@ findBucketElem(const XMLCh* const key, unsigned int& hashVal) const
     // Hash the key
     hashVal = XMLString::hash(key, fHashModulus, fMemoryManager);
 
-    if (hashVal > fHashModulus)
-        ThrowXMLwithMemMgr(RuntimeException, XMLExcepts::Pool_BadHashFromKey, fMemoryManager);
+    assert(hashVal < fHashModulus);
 
     // Search that bucket for the key
     const NameIdPoolBucketElem<TElem>* curElem = fBucketList[hashVal];
@@ -355,8 +314,9 @@ NameIdPoolEnumerator(NameIdPool<TElem>* const toEnum
 
 template <class TElem> NameIdPoolEnumerator<TElem>::
 NameIdPoolEnumerator(const NameIdPoolEnumerator<TElem>& toCopy) :
-
-    fCurIndex(toCopy.fCurIndex)
+    XMLEnumerator<TElem>(toCopy)
+    , XMemory(toCopy)
+    , fCurIndex(toCopy.fCurIndex)
     , fToEnum(toCopy.fToEnum)
     , fMemoryManager(toCopy.fMemoryManager)
 {
